diff --git a/CHANGELOG.md b/CHANGELOG.md
index d7dce1e88..6a288d950 100644
--- a/CHANGELOG.md
+++ b/CHANGELOG.md
@@ -1,4 +1,4 @@
-# v4.0.0-rc4
+# v4.0.0-rc5
- Improved the Schema Table update engine (more).
- Fix autoloader timing, and loading.
@@ -6,7 +6,9 @@
- Remove the SQL update, to only use the Schema updates of table columns to avoid collusion.
- Fix the admin.css file loading on dashboard. #1112
- Fix dynamic get data-type default to 0. #1110
-- Fix the missing model call. #1114
+- Fix the missing model call. #1114
+- Fix the wrong $date call. #1115
+- Add the BaseDatabaseModel use statement to custom site view controller. #1119
# v4.0.0-beta
diff --git a/ComponentbuilderInstallerScript.php b/ComponentbuilderInstallerScript.php
index 1c9781f44..2f87357a9 100644
--- a/ComponentbuilderInstallerScript.php
+++ b/ComponentbuilderInstallerScript.php
@@ -3210,7 +3210,7 @@ class Com_ComponentbuilderInstallerScript implements InstallerScriptInterface
echo '
-
Upgrade to Version 4.0.0-rc4 Was Successful! Let us know if anything is not working as expected.
';
+ Upgrade to Version 4.0.0-rc5 Was Successful! Let us know if anything is not working as expected.
';
// Add/Update component in the action logs extensions table.
$this->setActionLogsExtensions();
diff --git a/README.md b/README.md
index a01fdb388..3272d4cd2 100644
--- a/README.md
+++ b/README.md
@@ -9,7 +9,7 @@ The Component Builder for [Joomla](https://extensions.joomla.org/extension/compo
Whether you're a seasoned [Joomla](https://extensions.joomla.org/extension/component-builder/) developer, or have just started, Component Builder will save you lots of time and money. A real must have!
-You can install it quite easily and with no limitations. On [gitea](https://git.vdm.dev/joomla/Component-Builder/tags) is the latest release (4.0.0-rc4) with **ALL** its features and **ALL** concepts totally open-source and free!
+You can install it quite easily and with no limitations. On [gitea](https://git.vdm.dev/joomla/Component-Builder/tags) is the latest release (4.0.0-rc5) with **ALL** its features and **ALL** concepts totally open-source and free!
> Watch Quick Build of a Hello World component in [JCB on Youtube](https://www.youtube.com/watch?v=IQfsLYIeblk&list=PLQRGFI8XZ_wtGvPQZWBfDzzlERLQgpMRE&index=45)
@@ -145,10 +145,10 @@ TODO
+ *Name*: [Component Builder](https://git.vdm.dev/joomla/Component-Builder)
+ *First Build*: 30th April, 2015
+ *Last Build*: 3rd May, 2024
-+ *Version*: 4.0.0-rc4
++ *Version*: 4.0.0-rc5
+ *Copyright*: Copyright (C) 2015 Vast Development Method. All rights reserved.
+ *License*: GNU General Public License version 2 or later; see LICENSE.txt
-+ *Line count*: **746199**
++ *Line count*: **746201**
+ *Field count*: **2097**
+ *File count*: **5288**
+ *Folder count*: **528**
diff --git a/admin/README.txt b/admin/README.txt
index a01fdb388..3272d4cd2 100644
--- a/admin/README.txt
+++ b/admin/README.txt
@@ -9,7 +9,7 @@ The Component Builder for [Joomla](https://extensions.joomla.org/extension/compo
Whether you're a seasoned [Joomla](https://extensions.joomla.org/extension/component-builder/) developer, or have just started, Component Builder will save you lots of time and money. A real must have!
-You can install it quite easily and with no limitations. On [gitea](https://git.vdm.dev/joomla/Component-Builder/tags) is the latest release (4.0.0-rc4) with **ALL** its features and **ALL** concepts totally open-source and free!
+You can install it quite easily and with no limitations. On [gitea](https://git.vdm.dev/joomla/Component-Builder/tags) is the latest release (4.0.0-rc5) with **ALL** its features and **ALL** concepts totally open-source and free!
> Watch Quick Build of a Hello World component in [JCB on Youtube](https://www.youtube.com/watch?v=IQfsLYIeblk&list=PLQRGFI8XZ_wtGvPQZWBfDzzlERLQgpMRE&index=45)
@@ -145,10 +145,10 @@ TODO
+ *Name*: [Component Builder](https://git.vdm.dev/joomla/Component-Builder)
+ *First Build*: 30th April, 2015
+ *Last Build*: 3rd May, 2024
-+ *Version*: 4.0.0-rc4
++ *Version*: 4.0.0-rc5
+ *Copyright*: Copyright (C) 2015 Vast Development Method. All rights reserved.
+ *License*: GNU General Public License version 2 or later; see LICENSE.txt
-+ *Line count*: **746199**
++ *Line count*: **746201**
+ *Field count*: **2097**
+ *File count*: **5288**
+ *Folder count*: **528**
diff --git a/admin/compiler/joomla_4/SITE_ADMIN_VIEW_MODEL.php b/admin/compiler/joomla_4/SITE_ADMIN_VIEW_MODEL.php
index facbcf2c0..094431799 100644
--- a/admin/compiler/joomla_4/SITE_ADMIN_VIEW_MODEL.php
+++ b/admin/compiler/joomla_4/SITE_ADMIN_VIEW_MODEL.php
@@ -178,7 +178,7 @@ class ###View###Model extends AdminModel
*/
protected function prepareTable($table)
{###LICENSE_TABLE_LOCKED_CHECK###
- $date = $this->getDatabase();
+ $date = Factory::getDate();
$user = $this->getCurrentUser();
if (isset($table->name))
diff --git a/componentbuilder.xml b/componentbuilder.xml
index 23ce4426b..2d4e947b0 100644
--- a/componentbuilder.xml
+++ b/componentbuilder.xml
@@ -7,9 +7,9 @@
https://dev.vdm.io
Copyright (C) 2015 Vast Development Method. All rights reserved.
GNU General Public License version 2 or later; see LICENSE.txt
- 4.0.0-rc4
+ 4.0.0-rc5
Component Builder (v.4.0.0-rc4)
+ Component Builder (v.4.0.0-rc5)
The Component Builder for [Joomla](https://extensions.joomla.org/extension/component-builder/) is highly advanced tool that is truly able to build extremely complex components in a fraction of the time.
diff --git a/componentbuilder_update_server.xml b/componentbuilder_update_server.xml
index d21c928a4..447a91f6b 100644
--- a/componentbuilder_update_server.xml
+++ b/componentbuilder_update_server.xml
@@ -59,10 +59,10 @@
pkg_component_builder
package
site
- 4.0.0-rc4
+ 4.0.0-rc5
https://dev.vdm.io
- https://git.vdm.dev/api/v1/repos/joomla/pkg-component-builder/archive/v4.0.0-rc4.zip
+ https://git.vdm.dev/api/v1/repos/joomla/pkg-component-builder/archive/v4.0.0-rc5.zip
releasecandidate
diff --git a/admin/compiler/joomla_3/FormController_custom_site.php b/admin/compiler/joomla_3/FormController_custom_site.php
index 6f38faedb..7d5b7cb12 100644
--- a/admin/compiler/joomla_3/FormController_custom_site.php
+++ b/admin/compiler/joomla_3/FormController_custom_site.php
@@ -94,14 +94,14 @@ class ###Component###Controller###SView### extends FormController
* Function that allows child controller access to model data
* after the data has been saved.
*
* @param JModelLegacy $model The data model object.
* @param array $validData The validated data.
*
* @return void
*
- * @since 12.2
+ * @since 11.1
*/
- protected function postSaveHook(JModelLegacy $model, $validData = [])
+ protected function postSaveHook(BaseDatabaseModel $model, $validData = [])
{
}
}
@@ -94,14 +94,14 @@ class ###Component###Controller###SView### extends FormController
* after the data has been saved.
*
- * @param JModelLegacy $model The data model object.
- * @param array $validData The validated data.
+ * @param BaseDatabaseModel &$model The data model object.
+ * @param array $validData The validated data.
*
* @return void